@@ -742,11 +742,11 @@ https://github.com/sandialabs/compadre/blob/master/pycompadre/pycompadre.cpp
     sampling_functional["StaggeredEdgeIntegralSample"] = StaggeredEdgeIntegralSample;
     sampling_functional["VaryingManifoldVectorPointSample"] = VaryingManifoldVectorPointSample;
     sampling_functional["FaceNormalIntegralSample"] = FaceNormalIntegralSample;
-    sampling_functional["FaceNormalPointSample"] = FaceNormalPointSample;
-    sampling_functional["FaceTangentIntegralSample"] = FaceTangentIntegralSample;
-    sampling_functional["FaceTangentPointSample"] = FaceTangentPointSample;
-    sampling_functional["ScalarFaceAverageSample"] = ScalarFaceAverageSample;
-    sampling_functional["ScalarFaceIntegralSample"] = ScalarFaceIntegralSample;
+    sampling_functional["FaceNormalAverageSample"] = FaceNormalAverageSample;
+    sampling_functional["EdgeTangentIntegralSample"] = EdgeTangentIntegralSample;
+    sampling_functional["EdgeTangentAverageSample"] = EdgeTangentAverageSample;
+    sampling_functional["CellAverageSample"] = CellAverageSample;
+    sampling_functional["CellIntegralSample"] = CellIntegralSample;
     m.attr("SamplingFunctionals") = sampling_functional;
 
     py::enum_<TargetOperation>(m, "TargetOperation")
@@ -764,8 +764,12 @@ https://github.com/sandialabs/compadre/blob/master/pycompadre/pycompadre.cpp
     .value("PartialZOfScalarPointEvaluation", TargetOperation::PartialZOfScalarPointEvaluation)
     .value("ChainedStaggeredLaplacianOfScalarPointEvaluation", TargetOperation::ChainedStaggeredLaplacianOfScalarPointEvaluation)
     .value("GaussianCurvaturePointEvaluation", TargetOperation::GaussianCurvaturePointEvaluation)
-    .value("ScalarFaceAverageEvaluation", TargetOperation::ScalarFaceAverageEvaluation)
-    .value("ScalarFaceIntegralEvaluation", TargetOperation::ScalarFaceIntegralEvaluation)
+    .value("CellAverageEvaluation", TargetOperation::CellAverageEvaluation)
+    .value("CellIntegralEvaluation", TargetOperation::CellIntegralEvaluation)
+    .value("FaceNormalAverageEvaluation", TargetOperation::FaceNormalAverageEvaluation)
+    .value("FaceNormalIntegralEvaluation", TargetOperation::FaceNormalIntegralEvaluation)
+    .value("EdgeTangentAverageEvaluation", TargetOperation::EdgeTangentAverageEvaluation)
+    .value("EdgeTangentIntegralEvaluation", TargetOperation::EdgeTangentIntegralEvaluation)
     .export_values();
 
 
@@ -817,10 +821,12 @@ https://github.com/sandialabs/compadre/blob/master/pycompadre/pycompadre.cpp
     // helper functions
     py::class_<ParticleHelper>(m, "ParticleHelper", R"pbdoc(
         Class to manage calling PointCloudSearch, moving data to/from Numpy arrays in Kokkos::Views,
-        and applying GMLS solutions to multidimensional data arrays
+        and applying GMLS solutions to multidimensional data arrays 
     )pbdoc")
-    .def(py::init<>())
-    .def(py::init<GMLS*>(),py::arg("gmls_instance"))
+    .def(py::init<>(), R"pbdoc(
+        Requires follow-on call to setGMLSObject(gmls_obj) before use
+    )pbdoc")
+    .def(py::init<GMLS*>(), py::arg("gmls_instance"))
     .def("generateKDTree", overload_cast_<py::array_t<double> >()(&ParticleHelper::generateKDTree))
     .def("generateNeighborListsFromKNNSearchAndSet", &ParticleHelper::generateNeighborListsFromKNNSearchAndSet, 
             py::arg("target_sites"), py::arg("poly_order"), py::arg("dimension") = 3, py::arg("epsilon_multiplier") = 1.6, 
@@ -1054,10 +1060,39 @@ https://github.com/sandialabs/compadre/blob/master/pycompadre/pycompadre.cpp
         return convert_kokkos_to_np(quadrature.getSites());
     });
 
-    py::class_<KokkosParser>(m, "KokkosParser")
+    auto m_kokkos = m.def_submodule("Kokkos", R"pbdoc(
+        Namespace with a subset of Kokkos functionality. KokkosParser class should be preferred.
+    )pbdoc");
+    py::class_<Kokkos::InitArguments>(m_kokkos, "InitArguments")
+    .def(py::init<int, int, int, bool, bool>(), 
+            py::arg("num_threads") = -1, py::arg("num_numa") = -1, py::arg("device_id") = -1,
+            py::arg("disable_warnings") = false, py::arg("tune_internals") = false);
+
+    m_kokkos
+    .def("initialize", overload_cast_<Kokkos::InitArguments>()(&Kokkos::initialize), 
+            py::arg("init_args") = Kokkos::InitArguments())
+    .def("initialize", [](py::list args) {
+        std::vector<char*> char_args;
+        for (py::handle arg : args) {
+            char_args.push_back((char*)py::cast<std::string>(arg).data());
+        }
+        char_args.push_back(nullptr);
+        int argc = (int)args.size();
+        Kokkos::initialize(argc, char_args.data());     
+    })
+    .def("finalize", &Kokkos::finalize)
+    .def("is_initialized", &Kokkos::is_initialized)
+    .def("status", &KokkosParser::status);
+
+    py::class_<KokkosParser>(m, "KokkosParser", R"pbdoc(
+        Class wrapping the functionality of Kokkos::ScopeGuard. Multiple instances can  
+        can be instantiated and go out of scope with only one instance initiating Kokkos
+        and the last instance finalizing Kokkos when it goes out of scope.
+    )pbdoc")
+    .def(py::init<Kokkos::InitArguments,bool>(), py::arg("init_args"), py::arg("print") = false)
     .def(py::init<std::vector<std::string>,bool>(), py::arg("args"), py::arg("print") = false)
     .def(py::init<bool>(), py::arg("print") = false)
-    .def("status", &KokkosParser::status);
+    .def_static("status", &KokkosParser::status);
 
     m.def("getNP", &GMLS::getNP, R"pbdoc(
         Get size of basis.
